<?php
require __DIR__ . '/vendor/autoload.php';

use Dotenv\Dotenv;

// Load .env file
$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

// Database connection using environment variables
$dsn = 'mysql:host=' . $_ENV['DB_HOST'] . ';dbname=' . $_ENV['DB_NAME'];
$pdo = new PDO($dsn, $_ENV['DB_USER'], $_ENV['DB_PASSWORD'], [
    PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
    PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC
]);

// Fetch all restaurants for dropdown
$restaurants = $pdo->query("SELECT id, name FROM restaurants")->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FoodSpot - Failed Digital Payments</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/css/bootstrap.min.css">
    <style>
        .invoice-section {
            border: 1px solid #ddd;
            border-radius: 5px;
            padding: 15px;
            margin-top: 20px;
        }
        .invoice-section h4 {
            margin-bottom: 10px;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <h1>Failed Digital Payment Orders</h1>
    <form method="POST" class="mb-4">
        <div class="row">
            <div class="col-md-4">
                <label for="restaurant" class="form-label">Choose Restaurant</label>
                <select id="restaurant" name="restaurant_id" class="form-select" required>
                    <option value="" disabled selected>Select a restaurant</option>
                    <?php foreach ($restaurants as $restaurant): ?>
                        <option value="<?= htmlspecialchars($restaurant['id']) ?>"><?= htmlspecialchars($restaurant['name']) ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-3">
                <label for="start_date" class="form-label">Start Date</label>
                <input type="date" id="start_date" name="start_date" class="form-control">
            </div>
            <div class="col-md-3">
                <label for="end_date" class="form-label">End Date</label>
                <input type="date" id="end_date" name="end_date" class="form-control">
            </div>
            <div class="col-md-2 d-flex align-items-end">
                <button type="submit" class="btn btn-primary w-100">Submit</button>
            </div>
        </div>
    </form>

    <?php if ($_SERVER['REQUEST_METHOD'] === 'POST') : ?>
        <?php
        $restaurantId = $_POST['restaurant_id'];
        $startDate = $_POST['start_date'] ?: date('Y-m-d');
        $endDate = ($_POST['end_date'] ?: date('Y-m-d')) . ' 23:59:59'; // Include the full end date

        // Fetch orders with digital_payment and other criteria
        $stmt = $pdo->prepare("SELECT id, order_amount, payment_status, payment_method, created_at 
                               FROM orders 
                               WHERE restaurant_id = :restaurant_id 
                               AND created_at BETWEEN :start_date AND :end_date 
                               AND payment_method = 'digital_payment'
                               ORDER BY created_at ASC");
        $stmt->execute([
            'restaurant_id' => $restaurantId,
            'start_date' => $startDate,
            'end_date' => $endDate
        ]);

        $orders = $stmt->fetchAll();

        // Calculate totals for digital_payment orders
        $totalAmount = 0;
        ?>

        <h2>Orders List</h2>
        <?php if (count($orders) > 0): ?>
            <div class="table-responsive">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Order Amount</th>
                            <th>Payment Status</th>
                            <th>Payment Method</th>
                            <th>Created At</th>
                        </tr>
                    </thead>
                    <tbody>
                    <?php foreach ($orders as $order): ?>
                        <?php
                        $totalAmount += $order['order_amount'];
                        ?>
                        <tr>
                            <td><?= htmlspecialchars($order['id']) ?></td>
                            <td>£<?= number_format($order['order_amount'], 2) ?></td>
                            <td><?= ucfirst(htmlspecialchars($order['payment_status'])) ?></td>
                            <td><?= ucfirst(htmlspecialchars($order['payment_method'])) ?></td>
                            <td><?= date('Y-m-d', strtotime($order['created_at'])) ?></td>
                        </tr>
                    <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <div class="invoice-section">
                <h4>Invoice Summary</h4>
                <p><strong>Total Digital Payment Orders:</strong> <?= count($orders) ?> Orders, Total Amount: £<?= number_format($totalAmount, 2) ?></p>
            </div>
        <?php else: ?>
            <p>No digital payment orders found for the selected criteria.</p>
        <?php endif; ?>
    <?php else: ?>
        <?php
        // Default to current day if no POST data
        $today = date('Y-m-d');
        $stmt = $pdo->prepare("SELECT id, order_amount, payment_status, payment_method, created_at 
                               FROM orders 
                               WHERE restaurant_id IS NOT NULL 
                               AND created_at BETWEEN :start_date AND :end_date 
                               AND payment_method = 'digital_payment'
                               ORDER BY created_at ASC");
        $stmt->execute([
            'start_date' => $today . ' 00:00:00',
            'end_date' => $today . ' 23:59:59'
        ]);

        $orders = $stmt->fetchAll();
        ?>

        <h2>Orders List for Today</h2>
        <?php if (count($orders) > 0): ?>
            <div class="table-responsive">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Order Amount</th>
                            <th>Payment Status</th>
                            <th>Payment Method</th>
                            <th>Created At</th>
                        </tr>
                    </thead>
                    <tbody>
                    <?php foreach ($orders as $order): ?>
                        <?php
                        $totalAmount += $order['order_amount'];
                        ?>
                        <tr>
                            <td><?= htmlspecialchars($order['id']) ?></td>
                            <td>£<?= number_format($order['order_amount'], 2) ?></td>
                            <td><?= ucfirst(htmlspecialchars($order['payment_status'])) ?></td>
                            <td><?= ucfirst(htmlspecialchars($order['payment_method'])) ?></td>
                            <td><?= date('Y-m-d', strtotime($order['created_at'])) ?></td>
                        </tr>
                    <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <div class="invoice-section">
                <h4>Invoice Summary</h4>
                <p><strong>Total Digital Payment Orders:</strong> <?= count($orders) ?> Orders, Total Amount: £<?= number_format($totalAmount, 2) ?></p>
            </div>
        <?php else: ?>
            <p>No digital payment orders found for today.</p>
        <?php endif; ?>
    <?php endif; ?>
</div>
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.0/js/bootstrap.bundle.min.js"></script>
</body>
</html>
